==> members-facade-1.0.2-20190909.121006-263-sources.jar: com/bizvane/members/facade/models/po/MbrLabelTypeDefPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrLabelTypeDefPO implements Serializable {

  /**
   * 只读. 主键id. mbr_label_group_def_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "主键id", name = "mbrLabelGroupDefId", required = false, example = "")
  private Long mbrLabelGroupDefId;
  /**
   * 只读. 归属企业. sys_company_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "归属企业", name = "sysCompanyId", required = false, example = "")
  private Long sysCompanyId;
  /**
   * 只读. 归属品牌. brand_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "归属品牌", name = "brandId", required = false, example = "")
  private Long brandId;
  /**
   * 只读. 标签类型code. label_type_code
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "标签类型code", name = "labelTypeCode", required = false, example = "")
  private String labelTypeCode;
  /**
   * 只读. 标签类型名称. label_type_name
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "标签类型名称", name = "labelTypeName", required = false, example = "")
  private String labelTypeName;
  /**
   * 只读. 数据有效性：1=有效；0=无效. valid
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
  private Boolean valid;
  /**
   * 只读. 备注. remark
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
  private String remark;
  /**
   * 只读. 创建人id. create_user_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
  private Long createUserId;
  /**
   * 只读. 创建人. create_user_name
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "创建人", name = "createUserName", required = false, example = "")
  private String createUserName;
  /**
   * 只读. 创建日期. create_date
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
  private Date createDate;
  /**
   * 只读. 修改人id. modified_user_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
  private Long modifiedUserId;
  /**
   * 只读. 修改人. modified_user_name
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "修改人", name = "modifiedUserName", required = false, example = "")
  private String modifiedUserName;
  /**
   * 只读. 修改时间. modified_date
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
  private Date modifiedDate;
  /**
   * 只读. 版本号. version
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
  private Integer version;
  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  private static final long serialVersionUID = 1L;

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getMbrLabelGroupDefId() {
    return mbrLabelGroupDefId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setMbrLabelGroupDefId(Long mbrLabelGroupDefId) {
    this.mbrLabelGroupDefId = mbrLabelGroupDefId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getSysCompanyId() {
    return sysCompanyId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setSysCompanyId(Long sysCompanyId) {
    this.sysCompanyId = sysCompanyId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getBrandId() {
    return brandId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setBrandId(Long brandId) {
    this.brandId = brandId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getLabelTypeCode() {
    return labelTypeCode;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setLabelTypeCode(String labelTypeCode) {
    this.labelTypeCode = labelTypeCode == null ? null : labelTypeCode.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getLabelTypeName() {
    return labelTypeName;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setLabelTypeName(String labelTypeName) {
    this.labelTypeName = labelTypeName == null ? null : labelTypeName.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Boolean getValid() {
    return valid;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setValid(Boolean valid) {
    this.valid = valid;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getRemark() {
    return remark;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setRemark(String remark) {
    this.remark = remark == null ? null : remark.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getCreateUserId() {
    return createUserId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setCreateUserId(Long createUserId) {
    this.createUserId = createUserId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getCreateUserName() {
    return createUserName;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setCreateUserName(String createUserName) {
    this.createUserName = createUserName == null ? null : createUserName.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Date getCreateDate() {
    return createDate;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setCreateDate(Date createDate) {
    this.createDate = createDate;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getModifiedUserId() {
    return modifiedUserId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setModifiedUserId(Long modifiedUserId) {
    this.modifiedUserId = modifiedUserId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getModifiedUserName() {
    return modifiedUserName;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setModifiedUserName(String modifiedUserName) {
    this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Date getModifiedDate() {
    return modifiedDate;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setModifiedDate(Date modifiedDate) {
    this.modifiedDate = modifiedDate;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Integer getVersion() {
    return version;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setVersion(Integer version) {
    this.version = version;
  }
}

==> members-facade-2.1.4-20210630.023121-11-sources.jar: com/bizvane/members/facade/models/po/MbrLabelTypeDefPO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrLabelTypeDefPO implements Serializable {

  /**
   * 只读. 主键id. mbr_label_group_def_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "主键id", name = "mbrLabelGroupDefId", required = false, example = "")
  private Long mbrLabelGroupDefId;
  /**
   * 只读. 归属企业. sys_company_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "归属企业", name = "sysCompanyId", required = false, example = "")
  private Long sysCompanyId;
  /**
   * 只读. 归属品牌. brand_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "归属品牌", name = "brandId", required = false, example = "")
  private Long brandId;
  /**
   * 只读. 标签类型code. label_type_code
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "标签类型code", name = "labelTypeCode", required = false, example = "")
  private String labelTypeCode;
  /**
   * 只读. 标签类型名称. label_type_name
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "标签类型名称", name = "labelTypeName", required = false, example = "")
  private String labelTypeName;
  /**
   * 只读. 数据有效性：1=有效；0=无效. valid
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
  private Boolean valid;
  /**
   * 只读. 备注. remark
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
  private String remark;
  /**
   * 只读. 创建人id. create_user_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
  private Long createUserId;
  /**
   * 只读. 创建人. create_user_name
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "创建人", name = "createUserName", required = false, example = "")
  private String createUserName;
  /**
   * 只读. 创建日期. create_date
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "创建日期", name = "createDate", required = false, example = "")
  private Date createDate;
  /**
   * 只读. 修改人id. modified_user_id
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
  private Long modifiedUserId;
  /**
   * 只读. 修改人. modified_user_name
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "修改人", name = "modifiedUserName", required = false, example = "")
  private String modifiedUserName;
  /**
   * 只读. 修改时间. modified_date
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
  private Date modifiedDate;
  /**
   * 只读. 版本号. version
   * @mbg.generated  2018-11-26 17:20:34
   */
  @io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
  private Integer version;

  @io.swagger.annotations.ApiModelProperty(value = "排序字段",name = "sort",required = false,example = "")
  private Long sort;
  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  private static final long serialVersionUID = 1L;

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getMbrLabelGroupDefId() {
    return mbrLabelGroupDefId;
  }

  public Long getSort() {
    return sort;
  }

  public void setSort(Long sort) {
    this.sort = sort;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setMbrLabelGroupDefId(Long mbrLabelGroupDefId) {
    this.mbrLabelGroupDefId = mbrLabelGroupDefId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getSysCompanyId() {
    return sysCompanyId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setSysCompanyId(Long sysCompanyId) {
    this.sysCompanyId = sysCompanyId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getBrandId() {
    return brandId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setBrandId(Long brandId) {
    this.brandId = brandId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getLabelTypeCode() {
    return labelTypeCode;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setLabelTypeCode(String labelTypeCode) {
    this.labelTypeCode = labelTypeCode == null ? null : labelTypeCode.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getLabelTypeName() {
    return labelTypeName;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setLabelTypeName(String labelTypeName) {
    this.labelTypeName = labelTypeName == null ? null : labelTypeName.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Boolean getValid() {
    return valid;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setValid(Boolean valid) {
    this.valid = valid;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getRemark() {
    return remark;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setRemark(String remark) {
    this.remark = remark == null ? null : remark.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getCreateUserId() {
    return createUserId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setCreateUserId(Long createUserId) {
    this.createUserId = createUserId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getCreateUserName() {
    return createUserName;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setCreateUserName(String createUserName) {
    this.createUserName = createUserName == null ? null : createUserName.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Date getCreateDate() {
    return createDate;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setCreateDate(Date createDate) {
    this.createDate = createDate;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Long getModifiedUserId() {
    return modifiedUserId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setModifiedUserId(Long modifiedUserId) {
    this.modifiedUserId = modifiedUserId;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public String getModifiedUserName() {
    return modifiedUserName;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setModifiedUserName(String modifiedUserName) {
    this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Date getModifiedDate() {
    return modifiedDate;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setModifiedDate(Date modifiedDate) {
    this.modifiedDate = modifiedDate;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public Integer getVersion() {
    return version;
  }

  /**
   * 只读. 
   * @mbg.generated  2018-11-26 17:20:34
   */
  public void setVersion(Integer version) {
    this.version = version;
  }
}
